Tiny fake HIP data, partially processed by clean()
DF_TEST_TINI_CLEANED.RdTiny fake HIP data generated by data-raw/create_fake_HIP_data.R and
processed by clean
Fields
- title
Title code to indicate male or female hunter
- firstname
First name
- middle
Middle initial
- lastname
Last name
- suffix
Suffix
- address
Street or PO Box address
- city
City of residence
- state
State of residence
- zip
Zip code
- birth_date
Birth date
- issue_date
HIP registration date
- hunt_mig_birds
Code to indicate if hunter hunted migratory birds last season
- ducks_bag
Code to indicate duck harvest from last season
- geese_bag
Code to indicate goose harvest from last season
- dove_bag
Code to indicate dove harvest from last season
- woodcock_bag
Code to indicate woodcock harvest from last season
- coots_snipe
Code to indicate coot and snipe harvest from last season
- rails_gallinules
Code to indicate rail and gallinule harvest from last season
- cranes
Code to indicate crane harvest from last season
- band_tailed_pigeon
Code to indicate band-tailed pigeon harvest from last season
- brant
Code to indicate brant harvest from last season
- seaducks
Code to indicate sea duck harvest from last season
- registration_yr
Beginning year of the hunting season that HIP registration is valid for
Email address
- dl_state
HIP registration state
- dl_date
Date of HIP file
- source_file
File name that the record is from
- dl_cycle
Download cycle
- dl_key
Key for dl_state and dl_date combination
- record_key
Key for each record