Skip to contents

The internal btpiPermitBagFix function is used inside of clean to edit bag values for states that submit permit files separately from HIP. If records from these states submit a "2" for the band_tailed_pigeon field, they will be mistakenly identified as permit records. This function changes band_tailed_pigeon "2" values to "0" so that they are classified as HIP records until permit files are received later in the hunting season.

Usage

btpiPermitBagFix(raw_data)

Arguments

raw_data

The object created after reading in data with read_hip

Author

Abby Walter, abby_walter@fws.gov