Skip to contents

The internal checkFileNameDateFormat function is used inside of read_hip to return an error message if any file does not have a date formatted as YYYYMMDD.

Usage

checkFileNameDateFormat(file_list_vector)

Arguments

file_list_vector

A file list vector

Author

Abby Walter, abby_walter@fws.gov