Skip to contents

The internal checkFileNameStateAbbr function is used inside of read_hip to return an error message if any file does not have an state abbreviation from the expected 49 continental states.

Usage

checkFileNameStateAbbr(file_list_vector)

Arguments

file_list_vector

A file list vector

Author

Abby Walter, abby_walter@fws.gov