Skip to contents

After flagging errors in the data with proof, attempt corrections in all fields. Errors that cannot be programmatically corrected will be reported for manual correction.

Usage

correct(proofed_data, year)

Arguments

proofed_data

The object created after error flagging data with proof

year

The year in which the Harvest Information Program data were collected

See also

Author

Abby Walter, abby_walter@fws.gov