Skip to contents

The internal correctEmail function is used inside of correct to ...

Usage

correctEmail(proofed_data)

Arguments

proofed_data

The object created after error flagging data with proof

See also

Author

Abby Walter, abby_walter@fws.gov