Skip to contents

The internal correctMiddleInitial function changes non-alphabetic characters in the middle initial column to NA.

Usage

correctMiddleInitial(proofed_data)

Arguments

proofed_data

The object created after error flagging data with proof

See also

Author

Abby Walter, abby_walter@fws.gov