Skip to contents

The internal correctSuffix function is used inside of correct to change the value(s) in the suffix field to NA if an error is detected.

Usage

correctSuffix(proofed_data)

Arguments

proofed_data

The object created after error flagging data with proof

See also

Author

Abby Walter, abby_walter@fws.gov