Skip to contents

The internal correctTitle function is used inside of correct to change the value(s) in the title field to NA if an error is detected.

Usage

correctTitle(proofed_data)

Arguments

proofed_data

The object created after error flagging data with proof

See also

Author

Abby Walter, abby_walter@fws.gov