Skip to contents

The internal cranePermitBagFix function is used inside of clean to edit bag values for states that submit permit files separately from HIP. If records from these states submit a "2" for the crane field, they will be mistakenly identified as permit records. This function changes crane "2" values to "0" so that they are classified as HIP records until permit files are received later in the hunting season.

Usage

cranePermitBagFix(raw_data)

Arguments

raw_data

The object created after reading in data with read_hip

Author

Abby Walter, abby_walter@fws.gov