Skip to contents

The internal dropBlankFiles function is used inside of read_hip to return an error message if blank files exist in the directory, and remove them from the file list so they are not read in.

Usage

dropBlankFiles(filelist)

Arguments

filelist

The file list tibble created by listFiles

Author

Abby Walter, abby_walter@fws.gov