Skip to contents

Determine how many duplicate records are in the data and return a table.

Usage

duplicateFinder(current_data)

Arguments

current_data

The object created after filtering to current data with issueCheck

Author

Abby Walter, abby_walter@fws.gov