Skip to contents

Return a tibble of duplicates with a duplicate ID column identifying each group of records.

Usage

duplicateID(current_data)

Arguments

current_data

The object created after filtering to current data with issueCheck

Author

Abby Walter, abby_walter@fws.gov