Skip to contents

The internal errorLevelErrorsByField function calculates a summary table of the count of errors and proportion of erroneous values by field.

Usage

errorLevelErrorsByField(proofed_data)

Arguments

proofed_data

The object created after error flagging data with proof or correct

Author

Abby Walter, abby_walter@fws.gov