Skip to contents

The internal errorLevelErrorsByState function calculates a summary table of the count of errors, count of correct values, and proportion of erroneous values by state.

Usage

errorLevelErrorsByState(proofed_data)

Arguments

proofed_data

The object created after error flagging data with proof or correct

Author

Abby Walter, abby_walter@fws.gov