Skip to contents

Create a bar plot of errors by state, either by count or proportion.

Usage

errorPlotStates(proofed_data, threshold = NA)

Arguments

proofed_data

The object created after error flagging data with proof or correct

threshold

Optional. A decimal value above which error proportions should be plotted.

Author

Abby Walter, abby_walter@fws.gov