Skip to contents

Internal function that fails if a tibble without errors field (generated by proof) is provided.

Usage

failProofed(proofed_data)

Arguments

proofed_data

The object created after error flagging data with proof

Author

Abby Walter, abby_walter@fws.gov