Skip to contents

The internal getBadCity function is used inside of proof and qualityMessages to filter to city values that are not expected. Used by qCity.

Usage

getBadCity(data)

Arguments

data

Harvest Information Program registration data

Author

Abby Walter, abby_walter@fws.gov