Skip to contents

The internal getBadFirstName function is used inside of proof and qualityMessages to filter to firstname values that are not expected. Used by qFirstName.

Usage

getBadFirstName(data)

Arguments

data

Harvest Information Program registration data

Author

Abby Walter, abby_walter@fws.gov