Skip to contents

The internal getBadLastName function is used inside of proof and qualityMessages to filter to lastname values that are not expected. Used by qLastName.

Usage

getBadLastName(data)

Arguments

data

Harvest Information Program registration data

Author

Abby Walter, abby_walter@fws.gov