Skip to contents

The internal getBadMiddle function is used inside of proof and qualityMessages to filter to middle values that are not expected. Used by qMiddle.

Usage

getBadMiddle(data)

Arguments

data

Harvest Information Program registration data

Author

Abby Walter, abby_walter@fws.gov