Skip to contents

The internal getBadRegYear function is used inside of proof and qualityMessages to filter to registration_yr values that are not expected. We expect the registration_yr to equal the current hunting season.

Usage

getBadRegYear(data, year)

Arguments

data

Harvest Information Program registration data

year

The year in which the Harvest Information Program data were collected

Author

Abby Walter, abby_walter@fws.gov