Skip to contents

The internal getBadState function is used inside of proof and qualityMessages to filter to state values that are not expected. Used by qState.

Usage

getBadState(data)

Arguments

data

Harvest Information Program registration data

Author

Abby Walter, abby_walter@fws.gov