Skip to contents

The internal getBadSuffix function is used inside of proof and qualityMessages to filter to suffix values that are not expected. Used by qSuffix.

Usage

getBadSuffix(data)

Arguments

data

Harvest Information Program registration data

Author

Abby Walter, abby_walter@fws.gov