Skip to contents

The internal getBadTitle function is used inside of proof and qualityMessages to filter to title values that are not expected. Used by qTitle.

Usage

getBadTitle(data)

Arguments

data

Harvest Information Program registration data

Author

Abby Walter, abby_walter@fws.gov