Skip to contents

The internal getBadZIP function is used inside of proof and qualityMessages to filter to zip values that are not expected. Used by qZIP.

Usage

getBadZIP(data)

Arguments

data

Harvest Information Program registration data

Author

Abby Walter, abby_walter@fws.gov