Skip to contents

The internal interStateDuplicatesMessage function returns a message for duplicates found among files submitted from different states.

Usage

interStateDuplicatesMessage(raw_data, n_threshold = 100, p_threshold = 0.05)

Arguments

raw_data

The product of read_hip

n_threshold

A whole number; the threshold below which inter-state duplicates will not be reported, unless p_threshold is exceeded. Defaults to n = 100 inter-state duplicates.

p_threshold

A number ranging from 0 to 1; the threshold below which inter-state duplicates will not be reported, unless n_threshold is exceeded. Defaults to 0.05, or inter-state duplicates exceeding more than 5% of the number of submitted registrations by the first download state OR the second download state.

Author

Abby Walter, abby_walter@fws.gov