Skip to contents

The internal missingPIIFilter function filters out HIP registrations that are missing critical pieces of contact information.

Usage

missingPIIFilter(raw_data)

Arguments

raw_data

The object created after reading in data with read_hip

Author

Abby Walter, abby_walter@fws.gov