Skip to contents

Internal function that summarizes the number of dropped registrations.

Usage

nDropped(
  raw_data,
  clean_data,
  current_data,
  deduplicated_data,
  year,
  by_state = FALSE
)

Arguments

raw_data

The object created after reading in data with read_hip

clean_data

The object created after cleaning data with clean

current_data

The object created after filtering to current data with issueCheck

deduplicated_data

The object created after deduplicating data with duplicateFix

year

The year of the HIP season (e.g. 2022 for the 2022-2023 season)

by_state

TRUE summarizes the number of dropped records by state; FALSE (default) does not summarize

See also

Other summary functions: nDroppedClean(), nDroppedCurrent()

Author

Abby Walter, abby_walter@fws.gov