Skip to contents

Internal function that helps nDropped by summarizing the number of dropped registrations by clean.

Usage

nDroppedClean(raw_data, clean_data, by_state = FALSE)

Arguments

raw_data

The object created after reading in data with read_hip

clean_data

The object created after cleaning data with clean

by_state

TRUE summarizes the number of dropped records by state; FALSE (default) does not summarize

See also

Other summary functions: nDropped(), nDroppedCurrent()

Author

Abby Walter, abby_walter@fws.gov