Skip to contents

Internal function that helps nDropped by summarizing the number of dropped registrations by issueCheck.

Usage

nDroppedCurrent(clean_data, current_data, year)

Arguments

clean_data

The object created after cleaning data with clean

current_data

The object created after filtering to current data with issueCheck

year

The year of the HIP season (e.g. 2022 for the 2022-2023 season)

See also

Other summary functions: nDropped(), nDroppedClean()

Author

Abby Walter, abby_walter@fws.gov