Skip to contents

After data are deduplicated with duplicateFix, asses each field's values and flag records with unexpected or erroneous values in a new errors field.

Usage

proof(deduplicated_data, year)

Arguments

deduplicated_data

The object created after deduplicating data with duplicateFix

year

The year in which the Harvest Information Program data were collected

Author

Abby Walter, abby_walter@fws.gov