Skip to contents

Pull and view errors that have been flagged for a particular field. This function allows you to easily see what the proof function has determined to be unacceptable data.

Usage

pullErrors(proofed_data, field, unique = TRUE)

Arguments

proofed_data

The object created after error flagging data with proof

field

Field that should be pulled. Acceptable values include:

  • title, firstname, middle, lastname, suffix, address, city, state, zip, birth_date, issue_date, hunt_mig_birds, ducks_bag, geese_bag, dove_bag, woodcock_bag, coots_snipe, rails_gallinules, cranes, band_tailed_pigeon, brant, seaducks, registration_yr, email

unique

If FALSE, returns all error values; if TRUE (default), only returns unique values.

Author

Abby Walter, abby_walter@fws.gov