Skip to contents

The internal qBags function returns a messages for bad bag values, using internal helper functions zeroBagsMessage, naBagsMessage, and nonDigitBagsMessage.

Usage

qBags(raw_data)

Arguments

raw_data

The object created after reading in data with read_hip

Author

Abby Walter, abby_walter@fws.gov