Skip to contents

The internal qLastName function returns a message for bad lastname values. Uses internal helper getBadLastName.

Usage

qLastName(raw_data)

Arguments

raw_data

The object created after reading in data with read_hip

Author

Abby Walter, abby_walter@fws.gov