Skip to contents

The internal qTitle function returns a message for title values that are not assigned to the correct registrations. Uses internal helper getBadTitle.

Usage

qTitle(raw_data)

Arguments

raw_data

The object created after reading in data with read_hip

Author

Abby Walter, abby_walter@fws.gov