Skip to contents

The qualityMessages function is used to return messages for missing PII, missing email addresses, all-zero bag records, non-numeric bag values, bad title assignments, high proportions of non-resident hunters in a file, inter-state duplicates, low range of issue dates in a file, and low range of birth dates in a file.

Usage

qualityMessages(raw_data, year)

Arguments

raw_data

The product of read_hip

year

The year in which the Harvest Information Program data were collected

Author

Abby Walter, abby_walter@fws.gov