Question if correct year supplied
questionYear.RdInternal function that questions if the year supplied is intended to be different than the current season year by returning a message to the console.
Author
Abby Walter, abby_walter@fws.gov
questionYear.RdInternal function that questions if the year supplied is intended to be different than the current season year by returning a message to the console.
Abby Walter, abby_walter@fws.gov