Skip to contents

The internal readTimeMessage function returns a message to the console informing the user about how long it took to read in the data with read_hip.

Usage

readTimeMessage(raw_data, starttime, endtime)

Arguments

raw_data

Intermediate raw data tibble

starttime

Start time

endtime

End time

Author

Abby Walter, abby_walter@fws.gov