Read in data
read_hip.RdCompile data from state-exported text files by providing a path to the download directory.
Arguments
- path
File path to the folder containing HIP .txt files
- unique
Return a distinct frame? Defaults to TRUE
- state
When specified, reads in download data from a specified state. Must match a two-letter abbreviation for a US state (excluding HI).
- season
If set as TRUE, selects only folders starting with "DL" in a a season's upper-level directory
See also
Other reading functions:
checkFileNameDateFormat(),
checkFileNameStateAbbr(),
dropBlankFiles(),
dropBlankLines(),
idBlankFiles(),
ignoreHolds(),
ignoreLifetime(),
ignorePermits(),
listFiles(),
readTimeMessage()
Author
Abby Walter, abby_walter@fws.gov