Skip to contents

Create a tibble of error data by state or field. Data are reported using a threshold of proportion of error.

Usage

redFlags(proofed_data, type, threshold = 0)

Arguments

proofed_data

A proofed data table created by proof

type

Type of tibble to report. Acceptable values include:

  • state

  • field

threshold

Value above which errors should be tabulated

Author

Abby Walter, abby_walter@fws.gov