Skip to contents

Find and print any rows that have a line shift error with number of positions shifted.

Usage

shiftCheck(raw_data)

Arguments

raw_data

The object created after reading in data with read_hip

See also

glyphCheck()

Other shifting functions: shiftFinder()

Author

Abby Walter, abby_walter@fws.gov