Skip to contents

The internal shiftFinder function finds any rows that have a line shift error.

Usage

shiftFinder(raw_data)

Arguments

raw_data

The object created after reading in data with read_hip

See also

glyphFinder()

Other shifting functions: shiftCheck()

Author

Abby Walter, abby_walter@fws.gov