Return message if an issue date is after the file was submitted
timeTravelMessage.RdThe internal timeTravelMessage function is used inside of
issueMessages and issueCheck to return a message
if issue_date values are after the date the file was submitted.
Arguments
- issue_assignments
An intermediate tibble in
issueCheck
Author
Abby Walter, abby_walter@fws.gov