Skip to contents

The internal zipCheck function checks to see if zip codes in hunter addresses match the address state.

Usage

zipCheck(raw_data)

Arguments

raw_data

The object created after reading in data with read_hip

Author

Abby Walter, abby_walter@fws.gov