Correct data
correct.RdAfter flagging errors in the data with proof, attempt
corrections in all fields. Errors that cannot be programmatically corrected
will be reported for manual correction.
Arguments
- proofed_data
The object created after error flagging data with
proof- year
The year in which the Harvest Information Program data were collected
See also
Other correcting functions:
correctEmail(),
correctMiddleInitial(),
correctSuffix(),
correctTitle()
Author
Abby Walter, abby_walter@fws.gov