Drop blank files
dropBlankFiles.RdThe internal dropBlankFiles function is used inside of
read_hip to return an error message if blank files exist in the
directory, and remove them from the file list so they are not read in.
Arguments
- filelist
The file list tibble created by
listFiles
See also
Other reading functions:
checkFileNameDateFormat(),
checkFileNameStateAbbr(),
dropBlankLines(),
idBlankFiles(),
ignoreHolds(),
ignoreLifetime(),
ignorePermits(),
listFiles(),
readTimeMessage(),
read_hip()
Author
Abby Walter, abby_walter@fws.gov