Create a tibble of duplicates with an ID column
duplicateID.RdReturn a tibble of duplicates with a duplicate ID column identifying each group of records.
Arguments
- current_data
The object created after filtering to current data with
issueCheck
See also
Other deduplication functions:
duplicateAllOnes(),
duplicateAllOnesGroupSize(),
duplicateDecide(),
duplicateFields(),
duplicateFinder(),
duplicateFix(),
duplicateNewest(),
duplicatePlot(),
duplicateRecordType(),
duplicateSample()
Author
Abby Walter, abby_walter@fws.gov