Raw HIP file name correction
fileRename.RdThis function overwrites HIP filenames. Files in the supplied directory are renamed by converting the Julian date to YYYYMMDD format. State abbreviations that are in lowercase format are capitalized.
See also
Other file functions:
fileCheck()
Author
Abby Walter, abby_walter@fws.gov