Inter-state duplicates message
interStateDuplicatesMessage.RdThe internal interStateDuplicatesMessage function returns a message
for duplicates found among files submitted from different states.
Arguments
- raw_data
The product of
read_hip- n_threshold
A whole number; the threshold below which inter-state duplicates will not be reported, unless
p_thresholdis exceeded. Defaults to n = 100 inter-state duplicates.- p_threshold
A number ranging from 0 to 1; the threshold below which inter-state duplicates will not be reported, unless
n_thresholdis exceeded. Defaults to 0.05, or inter-state duplicates exceeding more than 5% of the number of submitted registrations by the first download state OR the second download state.
See also
Other quality functions:
inLinePermitDNHMessage(),
missingEmailsMessage(),
missingPIIMessage(),
naBagsMessage(),
nonDigitBagsMessage(),
nonResidentMessage(),
permitFileBagsMessage(),
qAddress(),
qBags(),
qBirthDate(),
qBirthDateRange(),
qCity(),
qFirstName(),
qHuntMigBirds(),
qIssueDateRange(),
qLastName(),
qMiddle(),
qRegistrationYear(),
qState(),
qSuffix(),
qSummary(),
qTitle(),
qZIP(),
qualityMessages(),
testRecordMessage(),
zeroBagsMessage()
Author
Abby Walter, abby_walter@fws.gov