Assign decisions to records using issue date and registration year
issueDecide.RdThe internal issueDecide function is used inside of
issueAssign and issueCheck to create the
decision field, which assigns records as current, past, future, etc;
no data changes are made other than creating the deicison field.
Arguments
- clean_data
The object created after cleaning data with
clean- year
The year of the HIP season (e.g. 2022 for the 2022-2023 season)
Author
Abby Walter, abby_walter@fws.gov