Summary table of how many registrations were dropped by issueCheck
nDroppedCurrent.RdInternal function that helps nDropped by summarizing the number
of dropped registrations by issueCheck.
Arguments
- clean_data
The object created after cleaning data with
clean- current_data
The object created after filtering to current data with
issueCheck- year
The year of the HIP season (e.g. 2022 for the 2022-2023 season)
See also
Other summary functions:
nDropped(),
nDroppedClean()
Author
Abby Walter, abby_walter@fws.gov