Return messages to console for common or catastrophic data quality issues
qualityMessages.RdThe qualityMessages function is used to return messages for missing
PII, missing email addresses, all-zero bag records, non-numeric bag values,
bad title assignments, high proportions of non-resident hunters in a file,
inter-state duplicates, low range of issue dates in a file, and low range of
birth dates in a file.
Arguments
- raw_data
The product of
read_hip- year
The year in which the Harvest Information Program data were collected
See also
Other quality functions:
inLinePermitDNHMessage(),
interStateDuplicatesMessage(),
missingEmailsMessage(),
missingPIIMessage(),
naBagsMessage(),
nonDigitBagsMessage(),
nonResidentMessage(),
permitFileBagsMessage(),
qAddress(),
qBags(),
qBirthDate(),
qBirthDateRange(),
qCity(),
qFirstName(),
qHuntMigBirds(),
qIssueDateRange(),
qLastName(),
qMiddle(),
qRegistrationYear(),
qState(),
qSuffix(),
qSummary(),
qTitle(),
qZIP(),
testRecordMessage(),
zeroBagsMessage()
Author
Abby Walter, abby_walter@fws.gov