Pull bad data
redFlags.RdCreate a tibble of error data by state or field. Data are reported using a threshold of proportion of error.
Arguments
- proofed_data
A proofed data table created by
proof- type
Type of tibble to report. Acceptable values include:
state
field
- threshold
Value above which errors should be tabulated
See also
Other error-finding functions:
errorLevelErrorsByField(),
errorLevelErrorsByState(),
errorPlotDL(),
errorPlotFields(),
errorPlotStates(),
errorTable(),
errorTableSummary(),
pullErrors()
Other plotting functions:
duplicatePlot(),
errorLevelErrorsByField(),
errorLevelErrorsByState(),
errorPlotDL(),
errorPlotFields(),
errorPlotStates(),
issuePlot(),
issuePlotDateLabel()
Author
Abby Walter, abby_walter@fws.gov