Modify corrected data table format and write as csv
write_hip.RdAfter correcting errors in the data with correct, this final
step will shape up the dataframe into a format ready for the database, and
write the data to csv.
Arguments
- corrected_data
The object created after correcting data with
correct- path
Directory for data to be written
- type
The type of HIP file being written out, one of: "HIP", "BT", or "CR"
- split
Split the output into one .csv file per .txt file? Default is TRUE.
See also
Other writing functions:
failWidths(),
writeReport()
Author
Abby Walter, abby_walter@fws.gov