Check if zip codes are associated with the correct state
zipCheck.RdThe internal zipCheck function checks to see if zip codes in hunter
addresses match the address state.
Arguments
- raw_data
The object created after reading in data with
read_hip
See also
Other cleaning functions:
btpiPermitBagFix(),
clean(),
cranePermitBagFix(),
formatZip(),
inLinePermitDNHFix(),
missingPIIFilter(),
moveSuffixes(),
namesToUppercase()
Author
Abby Walter, abby_walter@fws.gov